@@ -1,4 +1,4 @@
-// Copyright(C) 1999-2023 National Technology & Engineering Solutions
+// Copyright(C) 1999-, 20242024 National Technology & Engineering Solutions
 // of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 // NTESS, the U.S. Government retains certain rights in this software.
 //
@@ -35,28 +35,28 @@ namespace Ioss {
   {
   public:
     virtual ~IOFactory() = default;
-    static DatabaseIO *create(const std::string &type, const std::string &filename,
+    IOSS_NODISCARD static DatabaseIO *create(const std::string &type, const std::string &filename,
                               DatabaseUsage db_usage,
                               Ioss_MPI_Comm communicator = Ioss::ParallelUtils::comm_world(),
                               const Ioss::PropertyManager &properties = Ioss::PropertyManager());
 
     static int         describe(NameList *names);
-    static NameList    describe();
+    IOSS_NODISCARD static NameList    describe();
     static void        clean();
-    static std::string show_configuration();
+    IOSS_NODISCARD static std::string show_configuration();
 
   protected:
     explicit IOFactory(const std::string &type);
 
-    virtual DatabaseIO *make_IO(const std::string &filename, DatabaseUsage db_usage,
+    IOSS_NODISCARD virtual DatabaseIO *make_IO(const std::string &filename, DatabaseUsage db_usage,
                                 Ioss_MPI_Comm                communicator,
                                 const Ioss::PropertyManager &properties) const = 0;
 
-    virtual std::string show_config() const { return {""}; }
+    IOSS_NODISCARD virtual std::string show_config() const { return {""}; }
 
     static void alias(const std::string &base, const std::string &syn);
 
   private:
-    static IOFactoryMap *registry();
+    IOSS_NODISCARD static IOFactoryMap *registry();
   };
 } // namespace Ioss
